package com.chelvc.framework.database.context;

import java.util.Collections;
import java.util.List;

import com.chelvc.framework.database.entity.Entity;
import lombok.NonNull;
import org.apache.commons.lang3.tuple.Pair;

/**
 * 实体修改事件
 *
 * @author Woody
 * @date 2024/6/30
 */
public class EntityUpdateEvent extends EntityEvent {
    public EntityUpdateEvent(@NonNull Entity<?> entity) {
        this(entity, entity);
    }

    public EntityUpdateEvent(@NonNull Entity<?> before, @NonNull Entity<?> after) {
        this(Collections.singletonList(Pair.of(before, after)));
    }

    public EntityUpdateEvent(@NonNull List<Pair<Entity<?>, Entity<?>>> entities) {
        super(Collections.unmodifiableList(entities));
    }

    /**
     * 获取修改实体
     *
     * @return 实体对象实例列表
     */
    @SuppressWarnings("unchecked")
    public List<Pair<Entity<?>, Entity<?>>> getEntities() {
        return (List<Pair<Entity<?>, Entity<?>>>) this.source;
    }
}
