package com.chelvc.framework.database.support;

import java.io.Serializable;
import java.util.Collections;
import java.util.Map;
import java.util.stream.Collectors;

import com.baomidou.mybatisplus.core.metadata.TableInfo;
import com.chelvc.framework.common.util.ObjectUtils;
import lombok.Getter;
import lombok.NonNull;

/**
 * 表上下文对象
 *
 * @author Woody
 * @date 2025/1/5
 */
@Getter
public class Table implements Serializable {
    private final TableInfo info;
    private final Map<String, TableField> fields;

    public Table(@NonNull TableInfo info) {
        this.info = info;
        if (ObjectUtils.isEmpty(info.getFieldList())) {
            this.fields = Collections.emptyMap();
        } else {
            this.fields = Collections.unmodifiableMap(info.getFieldList().stream().collect(Collectors.toMap(
                    field -> MyBatisUtils.unquote(field.getColumn()), TableField::new
            )));
        }
    }

    /**
     * 获取数据模型
     *
     * @return 模型对象
     */
    public Class<?> getModel() {
        return this.info.getEntityType();
    }

    /**
     * 获取表字段
     *
     * @param field 字段名称
     * @return 表字段信息
     */
    public TableField getField(@NonNull String field) {
        return this.fields.get(MyBatisUtils.unquote(field));
    }
}
